Module sparse_status

Module sparse_status 

sparse_status constants.

Constants

CANNOT_SET_PROPERTY
sparse_status value returned when sparse_set_matrix_property rejects a property.
ILLEGAL_PARAMETER
sparse_status value returned when a sparse argument is invalid.
SUCCESS
sparse_status value returned for successful sparse operations.
SYSTEM_ERROR
sparse_status value returned when the sparse runtime reports a system failure.