Filter

Struct Filter 

pub struct Filter { /* private fields */ }
Thin owner for the deprecated-but-still-available BNNS filter APIs.

Implementations

Source

impl Filter

pub unsafe fn from_convolution( layer_params: *const c_void, filter_params: *const c_void, ) -> Option<Self>

Create a BNNS convolution filter from caller-owned raw layer/filter parameter structs.

Safety

The pointers must refer to valid BNNS parameter structs for the duration of the call.

pub unsafe fn from_fully_connected( layer_params: *const c_void, filter_params: *const c_void, ) -> Option<Self>

Create a BNNS fully connected filter from caller-owned raw layer/filter parameter structs.

Safety

The pointers must refer to valid BNNS parameter structs for the duration of the call.

pub const fn as_ptr(&self) -> *mut c_void

pub unsafe fn apply(&self, input: *const c_void, output: *mut c_void) -> i32

Apply the filter to caller-owned raw buffers.

Safety

input and output must match the layout and lengths described when the filter was created.