pub struct Filter { /* private fields */ }Expand description
Thin owner for the deprecated-but-still-available BNNS filter APIs.
Implementations
Sourceimpl Filter
impl Filter
Sourcepub unsafe fn from_convolution(
layer_params: *const c_void,
filter_params: *const c_void,
) -> Option<Self>
pub unsafe fn from_convolution( layer_params: *const c_void, filter_params: *const c_void, ) -> Option<Self>
Create a BNNS convolution filter from caller-owned raw layer/filter parameter structs.
Safety
The pointers must refer to valid BNNS parameter structs for the duration of the call.
Sourcepub unsafe fn from_fully_connected(
layer_params: *const c_void,
filter_params: *const c_void,
) -> Option<Self>
pub unsafe fn from_fully_connected( layer_params: *const c_void, filter_params: *const c_void, ) -> Option<Self>
Create a BNNS fully connected filter from caller-owned raw layer/filter parameter structs.
Safety
The pointers must refer to valid BNNS parameter structs for the duration of the call.
pub const fn as_ptr(&self) -> *mut c_void